@@ -10,7 +10,7 @@
 #'
 #' Bars depict means using \code{\link[ggplot2]{stat_summary}} with \code{geom = "bar", fun = "mean"} , and bar width is set to 0.7 (cannot be changed). Error bar width can be changed with the `ewid` argument.
 #' 
-#' Boxplot geometry uses \code{\link[ggplot2]{geom_boxplot}} with \code{position = position_dodge(width = 0.9), width = 0.6}. The thick line within the boxplot depicts the median, the box the IQR (interquantile range) and the whiskers show 1.5*IQR.
+#' Boxplot geometry uses \code{\link[ggplot2]{geom_boxplot}} with \code{position = position_dodge(width = 0.9), width = 0.6}. The thick line within the boxplot depicts the median, the box the IQR (interquartile range) and the whiskers show 1.5*IQR.
 #' 
 #' In 4d versions, the two grouping variables (i.e. `xcol` and either `boxes` or `bars`) are passed to ggplot aesthetics through \code{group = interaction{ xcol, shapes}}. 
 #'  
@@ -43,7 +43,9 @@
 #' @param facet_scales whether or not to fix scales on X & Y axes for all facet facet graphs. Can be `fixed` (default), `free`, `free_y` or `free_x` (for Y and X axis one at a time, respectively).
 #' @param fontsize parameter of \code{base_size} of fonts in \code{theme_classic}, default set to size 20.
 #' @param symthick size (in 'pt' units) of outline of symbol lines (\code{stroke}), default = `fontsize`/22.
-#' @param bvthick thickness (in 'pt' units) of both violin and boxplot lines; default = `fontsize`/22.
+#' @param bthick thickness (in 'pt' units) of boxplots; default = `fontsize`/22.
+#' @param vthick thickness (in 'pt' units) of violins; default = `fontsize`/22.
+#' @param bvthick thickness (in 'pt' units) of both violins and boxplots; default = `fontsize`/22.
 #' @param ColPal grafify colour palette to apply, default "okabe_ito"; see \code{\link{graf_palettes}} for available palettes.
 #' @param ColRev whether to reverse order of colour within the selected palette, default F (FALSE); can be set to T (TRUE).
 #' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
@@ -75,71 +77,63 @@
 #' boxes = Time, 
 #' shapes = Experiment)
 #' 
-plot_3d_scatterviolin <- function(data, xcol, ycol, shapes, facet, symsize = 3, s_alpha = 0.8, b_alpha = 0, v_alpha = 1, bwid = 0.3, vadjust = 1, jitter = 0.1,  TextXAngle = 0, scale = "width", trim = TRUE, LogYTrans, LogYBreaks = waiver(), LogYLabels = waiver(), LogYLimits = NULL, facet_scales = "fixed", fontsize = 20, symthick, bvthick, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColSeq = TRUE, ColRev = FALSE, SingleColour = "NULL", ...){
+
+plot_3d_scatterviolin <- function(data, xcol, ycol, shapes, facet, symsize = 3, s_alpha = 0.8, b_alpha = 0, v_alpha = 1, bwid = 0.3, vadjust = 1, jitter = 0.1,  TextXAngle = 0, scale = "width", trim = TRUE, LogYTrans, LogYBreaks = waiver(), LogYLabels = waiver(), LogYLimits = NULL, facet_scales = "fixed", fontsize = 20, symthick, bthick, vthick, bvthick, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColSeq = TRUE, ColRev = FALSE, SingleColour = "NULL", ...){
   ColPal <- match.arg(ColPal)
+  if(!missing(bvthick)) {
+    bthick = bvthick
+    vthick = bvthick}
+  if(missing(bthick)) {bthick = fontsize/22}
+  if(missing(vthick)) {vthick = fontsize/22}
   if (missing(symthick)) {symthick = fontsize/22}
-  if(missing(bvthick)) {bvthick = fontsize/22}
+  suppressWarnings(P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
+                                                  y = {{ ycol }},
+                                                  group = factor({{ xcol }})))+
+                     geom_violin(aes(fill = factor({{ xcol }})),
+                                 size = vthick,
+                                 alpha = v_alpha,
+                                 scale = scale,
+                                 position = position_dodge(width = 0.8),
+                                 colour = "black",
+                                 adjust = vadjust,
+                                 trim = trim, ...)+
+                     scale_shape_manual(values = 0:25)+
+                     labs(x = enquo(xcol),
+                          fill = enquo(xcol),
+                          shape = enquo(shapes)))
   if (b_alpha == 0){
-    P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
-                                   y = {{ ycol }},
-                                   group = factor({{ xcol }})))+
-      geom_violin(aes(fill = factor({{ xcol }})),
-                  size = bvthick,
-                  alpha = v_alpha,
-                  scale = scale,
-                  position = position_dodge(width = 0.8),
-                  colour = "black",
-                  adjust = vadjust,
-                  trim = trim, ...)+
-      geom_boxplot(aes(fill = factor({{ xcol }})), 
-                   fill = "white",
-                   size = bvthick,
-                   position = position_dodge(width = 0.8),
-                   width = bwid,
-                   outlier.alpha = 0, 
-                   colour = "black",
-                   ...)+
-      geom_point(size = symsize, 
-                 stroke = symthick,
-                 alpha = s_alpha, 
-                 colour = "black",
-                 position = position_jitterdodge(jitter.width = jitter,
-                                                 dodge.width = 0.8),
-                 aes(shape = factor({{ shapes }})))+
-      scale_shape_manual(values = 0:25)+
-      labs(x = enquo(xcol),
-           fill = enquo(xcol),
-           shape = enquo(shapes))
+    suppressWarnings(P <- P +
+                       geom_boxplot(aes(fill = factor({{ xcol }})), 
+                                    fill = "white",
+                                    size = bthick,
+                                    position = position_dodge(width = 0.8),
+                                    width = bwid,
+                                    outlier.alpha = 0, 
+                                    colour = "black",
+                                    ...)+
+                       geom_point(size = symsize, 
+                                  stroke = symthick,
+                                  alpha = s_alpha, 
+                                  colour = "black",
+                                  position = position_jitterdodge(jitter.width = jitter,
+                                                                  dodge.width = 0.8),
+                                  aes(shape = factor({{ shapes }}))))
   } else {
-    P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
-                                   y = {{ ycol }},
-                                   group = factor({{ xcol }})))+
-      geom_violin(aes(fill = factor({{ xcol }})),
-                  size = bvthick,
-                  alpha = v_alpha,
-                  scale = scale,
-                  position = position_dodge(width = 0.8),
-                  colour = "black", 
-                  adjust = vadjust,
-                  trim = trim, ...)+
-      geom_boxplot(aes(fill = factor({{ xcol }})), 
-                   size = bvthick,
-                   alpha = b_alpha,
-                   position = position_dodge(width = 0.8),
-                   width = bwid,
-                   outlier.alpha = 0, 
-                   colour = "black",
-                   ...)+
-      geom_point(size = symsize, 
-                 stroke = symthick,
-                 alpha = s_alpha, colour = "black",
-                 position = position_jitterdodge(jitter.width = jitter,
-                                                 dodge.width = 0.8),
-                 aes(shape = factor({{ shapes }})))+
-      scale_shape_manual(values = 0:25)+
-      labs(x = enquo(xcol),
-           fill = enquo(xcol),
-           shape = enquo(shapes))
+    suppressWarnings(P <- P +
+                       geom_boxplot(aes(fill = factor({{ xcol }})), 
+                                    size = bthick,
+                                    alpha = b_alpha,
+                                    position = position_dodge(width = 0.8),
+                                    width = bwid,
+                                    outlier.alpha = 0, 
+                                    colour = "black",
+                                    ...)+
+                       geom_point(size = symsize, 
+                                  stroke = symthick,
+                                  alpha = s_alpha, colour = "black",
+                                  position = position_jitterdodge(jitter.width = jitter,
+                                                                  dodge.width = 0.8),
+                                  aes(shape = factor({{ shapes }}))))
   }
   if(!missing(facet)) {
     P <- P + facet_wrap(vars({{ facet }}), 
@@ -159,9 +153,9 @@ plot_3d_scatterviolin <- function(data, xcol, ycol, shapes, facet, symsize = 3,
                            ...)+
         annotation_logticks(sides = "l", 
                             outside = TRUE,
-                            base = 10,
-                            long = unit(0.2, "cm"), 
-                            mid = unit(0.1, "cm"),
+                            base = 10, color = "grey20",
+                            long = unit(7*fontsize/22, "pt"), size = unit(fontsize/22, "pt"),# 
+                            short = unit(4*fontsize/22, "pt"), mid = unit(4*fontsize/22, "pt"),#
                             ...)+ 
         coord_cartesian(clip = "off", ...)
     }
@@ -179,24 +173,20 @@ plot_3d_scatterviolin <- function(data, xcol, ycol, shapes, facet, symsize = 3,
            ifelse(isTRUE(get_graf_colours(SingleColour) != 0), 
                   a <- unname(get_graf_colours(SingleColour)), 
                   a <- SingleColour))
-    x1 <- deparse(substitute(xcol))
-    x <- length(levels(factor(data[[x1]])))
-    P <- P + 
-      scale_fill_manual(values = rep(a, 
-                                     times = x))+
-      guides(x = guide_axis(angle = TextXAngle),
-             fill = "none")
+    col <- deparse(substitute(xcol))
+    len <- length(levels(factor(data[[col]])))
+    suppressWarnings(P <- P + 
+                       scale_fill_manual(values = rep(a, len)))
   } else {
-    P <- P +
-      scale_fill_grafify(palette = ColPal,
-                         reverse = ColRev,
-                         ColSeq = ColSeq)+
-      guides(x = guide_axis(angle = TextXAngle),
-             fill = guide_legend(order = 1),
-             shape = guide_legend(order = 2))
+    suppressWarnings(P <- P +
+                       scale_fill_grafify(palette = ColPal, 
+                                          reverse = ColRev, 
+                                          ColSeq = ColSeq))
   }
   P <- P +
-    theme_classic(base_size = fontsize)+
-    theme(strip.background = element_blank())
+    guides(x = guide_axis(angle = TextXAngle),
+           fill = guide_legend(order = 1),
+           shape = guide_legend(order = 2))+
+    theme_grafify(base_size = fontsize)
   P
 }
