@@ -37,7 +37,8 @@
 #' @param facet_scales whether or not to fix scales on X & Y axes for all facet facet graphs. Can be `fixed` (default), `free`, `free_y` or `free_x` (for Y and X axis one at a time, respectively).
 #' @param fontsize parameter of \code{base_size} of fonts in \code{theme_classic}, default set to size 20.
 #' @param symthick size (in 'pt' units) of outline of symbol lines (\code{stroke}), default = `fontsize`/22.
-#' @param bthick thickness (in 'pt' units) of lines and boxes lines; default = `fontsize`/22.
+#' @param bthick thickness (in 'pt' units) of boxes; default = `(fontsize)/22`.
+#' @param lthick thickness (in 'pt' units) of lines; default = `(fontsize/1.2)/22`.
 #' @param ColPal grafify colour palette to apply, default "okabe_ito"; see \code{\link{graf_palettes}} for available palettes.
 #' @param ColSeq logical TRUE or FALSE. Default TRUE for sequential colours from chosen palette. Set to FALSE for distant colours, which will be applied using  \code{scale_fill_grafify2}.
 #' @param ColRev whether to reverse order of colour within the selected palette, default F (FALSE); can be set to T (TRUE).
@@ -63,11 +64,12 @@
 #' match = Experiment, facet = Genotype)
 #'
 
-plot_befafter_box <- function(data, xcol, ycol, match, facet, PlotShapes = FALSE, symsize = 3,  s_alpha = 0.8, b_alpha = 1, bwid = 0.4, jitter = 0.1, TextXAngle = 0, LogYTrans, LogYBreaks = waiver(), LogYLabels = waiver(), LogYLimits = NULL, facet_scales = "fixed", fontsize = 20, symthick, bthick, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColSeq = TRUE, ColRev = FALSE, SingleColour = "NULL", ...){
+plot_befafter_box <- function(data, xcol, ycol, match, facet, PlotShapes = FALSE, symsize = 3,  s_alpha = 0.8, b_alpha = 1, bwid = 0.4, jitter = 0.1, TextXAngle = 0, LogYTrans, LogYBreaks = waiver(), LogYLabels = waiver(), LogYLimits = NULL, facet_scales = "fixed", fontsize = 20, symthick, bthick, lthick, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColSeq = TRUE, ColRev = FALSE, SingleColour = "NULL", ...){
   ColPal <- match.arg(ColPal)
-  if (missing(bthick)) {bthick = (fontsize/1.5)/22}
+  if (missing(bthick)) {bthick = (fontsize)/22}
+  if (missing(lthick)) {lthick = (fontsize/1.5)/22}
   if (missing(symthick)) {symthick = (fontsize)/22}
-  P <- ggplot2::ggplot(data, 
+  suppressWarnings(P <- ggplot2::ggplot(data, 
                        aes(x = factor({{ xcol }}),
                            y = {{ ycol }},
                            group = factor({{ match }})))+
@@ -81,11 +83,11 @@ plot_befafter_box <- function(data, xcol, ycol, match, facet, PlotShapes = FALSE
     geom_line(aes(group = factor({{ match }})),
               colour = "grey35", 
               alpha = 0.8, 
-              size = bthick, 
+              size = lthick, 
               position = position_dodge(width = jitter),
-              ...)
+              ...))
   if (!PlotShapes) {
-    P <- P + 
+    suppressWarnings(P <- P + 
       geom_point(size = symsize, 
                  stroke = symthick,
                  alpha = s_alpha, 
@@ -93,9 +95,9 @@ plot_befafter_box <- function(data, xcol, ycol, match, facet, PlotShapes = FALSE
                  position = position_dodge(width = jitter),
                  aes(fill = factor({{ xcol }})), ...)+
       labs(fill = enquo(xcol),
-           x = enquo(xcol))
+           x = enquo(xcol)))
   } else {
-    P <- P + 
+    suppressWarnings(P <- P + 
       geom_point(size = symsize, 
                  stroke = symthick,
                  alpha = s_alpha,
@@ -106,7 +108,7 @@ plot_befafter_box <- function(data, xcol, ycol, match, facet, PlotShapes = FALSE
       scale_shape_manual(values = 0:25)+
       labs(fill = enquo(xcol),
            x = enquo(xcol),
-           shape = enquo(match))
+           shape = enquo(match)))
   }
   if(!missing(facet)) {
     P <- P + facet_wrap(vars({{ facet }}), 
@@ -126,9 +128,9 @@ plot_befafter_box <- function(data, xcol, ycol, match, facet, PlotShapes = FALSE
                            ...)+
         annotation_logticks(sides = "l", 
                             outside = TRUE,
-                            base = 10,
-                            long = unit(0.2, "cm"), 
-                            mid = unit(0.1, "cm"),
+                            base = 10, color = "grey20",
+                            long = unit(7*fontsize/22, "pt"), size = unit(fontsize/22, "pt"),# 
+                            short = unit(4*fontsize/22, "pt"), mid = unit(4*fontsize/22, "pt"),#
                             ...)+ 
         coord_cartesian(clip = "off", ...)
     }
@@ -164,7 +166,6 @@ plot_befafter_box <- function(data, xcol, ycol, match, facet, PlotShapes = FALSE
              shape = guide_legend(order = 2))
   }
   P <- P +
-    theme_classic(base_size = fontsize)+
-    theme(strip.background = element_blank())
+    theme_grafify(base_size = fontsize)
   P
 }
