@@ -65,22 +65,22 @@ plot_dotbar_sd <- function(data, xcol, ycol, facet, ErrorType = "SD", dotsize =
   if(ErrorType == "CI95") {ER <- "mean_cl_normal"}
   if (missing(bthick)) {bthick = fontsize/22}
   if (missing(dotthick)) {dotthick = fontsize/22}
-  P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
-                                 y = {{ ycol }}))+
-    stat_summary(geom = "bar", 
-                 colour = "black", 
-                 width = bwid,
-                 fun = "mean", 
-                 alpha = b_alpha, 
-                 size = bthick,
-                 aes(fill = factor({{ xcol }})))+
-    geom_dotplot(dotsize = dotsize, 
-                 stroke = dotthick,
-                 binaxis = 'y', 
-                 alpha = d_alpha,
-                 stackdir = 'center',
-                 aes(fill = factor({{ xcol }})),
-                 ...)
+  suppressWarnings(P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
+                                                  y = {{ ycol }}))+
+                     stat_summary(geom = "bar", 
+                                  colour = "black", 
+                                  width = bwid,
+                                  fun = "mean", 
+                                  alpha = b_alpha, 
+                                  size = bthick,
+                                  aes(fill = factor({{ xcol }})))+
+                     geom_dotplot(dotsize = dotsize, 
+                                  stroke = dotthick,
+                                  binaxis = 'y', 
+                                  alpha = d_alpha,
+                                  stackdir = 'center',
+                                  aes(fill = factor({{ xcol }})),
+                                  ...))
   if (ER == "mean_cl_normal") {
     P <- P + stat_summary(geom = "errorbar", 
                           size = bthick,
@@ -93,12 +93,6 @@ plot_dotbar_sd <- function(data, xcol, ycol, facet, ErrorType = "SD", dotsize =
                           fun.args = list(mult = 1),
                           width = ewid) 
   }
-  P <- P  +
-    labs(x = enquo(xcol),
-         fill = enquo(xcol))+
-    theme_classic(base_size = fontsize)+
-    theme(strip.background = element_blank())+
-    guides(x = guide_axis(angle = TextXAngle))
   #add facets
   if(!missing(facet)) {
     P <- P + facet_wrap(vars({{ facet }}), 
@@ -119,9 +113,9 @@ plot_dotbar_sd <- function(data, xcol, ycol, facet, ErrorType = "SD", dotsize =
                            ...)+
         annotation_logticks(sides = "l", 
                             outside = TRUE,
-                            base = 10,
-                            long = unit(0.2, "cm"), 
-                            mid = unit(0.1, "cm"),
+                            base = 10, color = "grey20",
+                            long = unit(7*fontsize/22, "pt"), size = unit(fontsize/22, "pt"),# 
+                            short = unit(4*fontsize/22, "pt"), mid = unit(4*fontsize/22, "pt"),#
                             ...)+ 
         coord_cartesian(clip = "off", ...)
     }
@@ -153,5 +147,10 @@ plot_dotbar_sd <- function(data, xcol, ycol, facet, ErrorType = "SD", dotsize =
                          reverse = ColRev, 
                          ColSeq = ColSeq)
   }
+  P <- P  +
+    labs(x = enquo(xcol),
+         fill = enquo(xcol))+
+    theme_grafify(base_size = fontsize)+
+    guides(x = guide_axis(angle = TextXAngle))
   P
 }
