@@ -67,7 +67,7 @@ plot_scatterbar_sd <- function(data, xcol, ycol, facet, ErrorType = "SD", symsiz
   if(ErrorType == "CI95") {ER <- "mean_cl_normal"}
   if (missing(bthick)) {bthick = fontsize/22}
   if (missing(symthick)) {symthick = fontsize/22}
-  P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
+  suppressWarnings(P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
                                  y = {{ ycol }}))+
     stat_summary(geom = "bar", 
                  colour = "black", 
@@ -80,7 +80,7 @@ plot_scatterbar_sd <- function(data, xcol, ycol, facet, ErrorType = "SD", symsiz
                alpha = s_alpha, shape = 21,
                position = position_jitter(width = jitter), 
                stroke = symthick,
-               aes(fill = factor({{ xcol }})))
+               aes(fill = factor({{ xcol }}))))
   if (ER == "mean_cl_normal") {
     P <- P + stat_summary(geom = "errorbar", 
                           size = bthick,
@@ -96,8 +96,7 @@ plot_scatterbar_sd <- function(data, xcol, ycol, facet, ErrorType = "SD", symsiz
   P <- P +
     labs(x = enquo(xcol),
          fill = enquo(xcol))+
-    theme_classic(base_size = fontsize)+
-    theme(strip.background = element_blank())+
+    theme_grafify(base_size = fontsize)+
     guides(x = guide_axis(angle = TextXAngle))
   
   #add facets
@@ -120,9 +119,9 @@ plot_scatterbar_sd <- function(data, xcol, ycol, facet, ErrorType = "SD", symsiz
                            ...)+
         annotation_logticks(sides = "l", 
                             outside = TRUE,
-                            base = 10,
-                            long = unit(0.2, "cm"), 
-                            mid = unit(0.1, "cm"),
+                            base = 10, color = "grey20",
+                            long = unit(7*fontsize/22, "pt"), size = unit(fontsize/22, "pt"),# 
+                            short = unit(4*fontsize/22, "pt"), mid = unit(4*fontsize/22, "pt"),#
                             ...)+ 
         coord_cartesian(clip = "off", ...)
     }
